@@ -17,7 +17,7 @@ class QStringList;
 
 class ServerRepo;
 class Account;
-class StarredFile;
+class StarredItem;
 class SeafEvent;
 class CommitDetails;
 
@@ -80,9 +80,6 @@ class RepoDownloadInfo
 {
 public:
     int repo_version;
-    QString relay_id;
-    QString relay_addr;
-    QString relay_port;
     QString email;
     QString token;
     QString repo_id;
@@ -158,6 +155,15 @@ public:
                       const QString& repo_id,
                       const QString& magic,
                       const QString& random_key);
+    // Constructor for seafile encryption v3
+    CreateRepoRequest(const Account& account,
+                      const QString& name,
+                      const QString& desc,
+                      int enc_version,
+                      const QString& repo_id,
+                      const QString& magic,
+                      const QString& random_key,
+                      const QString& salt);
 
 protected slots:
     void requestSuccess(QNetworkReply& reply);
@@ -246,7 +252,7 @@ public:
     GetStarredFilesRequest(const Account& account);
 
 signals:
-    void success(const std::vector<StarredFile>& starred_files);
+    void success(const std::vector<StarredItem>& starred_files);
 
 protected slots:
     void requestSuccess(QNetworkReply& reply);
@@ -255,6 +261,23 @@ private:
     Q_DISABLE_COPY(GetStarredFilesRequest);
 };
 
+// get starred item api v2.1
+class GetStarredFilesRequestV2 : public SeafileApiRequest
+{
+Q_OBJECT
+public:
+    GetStarredFilesRequestV2(const Account& account);
+
+signals:
+    void success(const std::vector<StarredItem>& starred_files);
+
+protected slots:
+    void requestSuccess(QNetworkReply& reply);
+
+private:
+    Q_DISABLE_COPY(GetStarredFilesRequestV2);
+};
+
 class GetEventsRequest : public SeafileApiRequest
 {
     Q_OBJECT
@@ -271,6 +294,22 @@ private:
     Q_DISABLE_COPY(GetEventsRequest);
 };
 
+class GetEventsRequestV2 : public SeafileApiRequest
+{
+    Q_OBJECT
+public:
+    GetEventsRequestV2(const Account& account, int page = 1, int perpage = 25, int avatar_size = 36);
+
+signals:
+    void success(const std::vector<SeafEvent>& events);
+
+protected slots:
+    void requestSuccess(QNetworkReply& reply);
+
+private:
+    Q_DISABLE_COPY(GetEventsRequestV2);
+};
+
 class GetCommitDetailsRequest : public SeafileApiRequest
 {
     Q_OBJECT
@@ -379,7 +418,7 @@ protected slots:
 
 private:
     Q_DISABLE_COPY(ServerInfoRequest);
-    const Account& account_;
+    const Account account_;
 };
 
 class LogoutDeviceRequest : public SeafileApiRequest
@@ -471,7 +510,7 @@ private:
 
     Account account_;
     QStringList repo_ids_;
-    QMap<QString, QString> repo_tokens_;
+    QMultiMap<QString, QString> repo_tokens_;
     int max_retries_;
 
     // The start position of the next batch
@@ -518,6 +557,7 @@ struct FileSearchResult {
     qint64 last_modified;
     QString fullpath;
     qint64 size;
+    bool is_dir;
 };
 
 Q_DECLARE_METATYPE(FileSearchResult)
